/// Server configuration to use
enum Environment {
  dev,
  sandbox,
  beta,
  prod,
}

extension EnvironmentExtension on Environment {
  static Environment fromString(String environment) {
    switch (environment) {
      case 'dev':
        return Environment.dev;
      case 'sandbox':
        return Environment.sandbox;
      case 'beta':
        return Environment.beta;
      case 'prod':
        return Environment.prod;
      default:
        throw Exception('Unknown environment');
    }
  }

  Uri jsBridgeUri() {
    switch (this) {
      case Environment.dev:
        return Uri.parse('http://localhost:3004/');
      case Environment.sandbox:
        return Uri.parse('https://js-bridge.sandbox.usecapsule.com/');
      case Environment.beta:
        return Uri.parse('https://js-bridge.beta.usecapsule.com/');
      case Environment.prod:
        return Uri.parse('https://js-bridge.prod.usecapsule.com/');
    }
  }

  String relyingPartyId() {
    switch (this) {
      case Environment.dev:
        throw Exception(
            'Custom relying party ID is required for dev environment');
      case Environment.sandbox:
        return 'app.sandbox.usecapsule.com';
      case Environment.beta:
        return 'app.beta.usecapsule.com';
      case Environment.prod:
        return 'app.usecapsule.com';
    }
  }
}
