import 'package:flutter_test/flutter_test.dart';

import 'package:capsule/capsule.dart';

void main() {
  testWidgets('initializes a Capsule', (tester) async {
    Capsule capsule = Capsule(environment: Environment.beta, apiKey: '123456');
    capsule.init();
  });

  testWidgets('Environment string conversion checks', (tester) async {
    Environment env = EnvironmentExtension.fromString('dev');
    expect(env, Environment.dev);
    env = EnvironmentExtension.fromString('sandbox');
    expect(env, Environment.sandbox);
    env = EnvironmentExtension.fromString('beta');
    expect(env, Environment.beta);
    env = EnvironmentExtension.fromString('prod');
    expect(env, Environment.prod);
  });

  testWidgets('Environment jsBridgeUri checks', (tester) async {
    Uri uri = Environment.dev.jsBridgeUri();
    expect(uri, Uri.parse('http://localhost:3004/'));
    uri = Environment.sandbox.jsBridgeUri();
    expect(uri, Uri.parse('https://js-bridge.sandbox.usecapsule.com/'));
    uri = Environment.beta.jsBridgeUri();
    expect(uri, Uri.parse('https://js-bridge.beta.usecapsule.com/'));
    uri = Environment.prod.jsBridgeUri();
    expect(uri, Uri.parse('https://js-bridge.prod.usecapsule.com/'));
  });

  testWidgets('Capsule overrides work as expected ', (widgetTester) async {
    Capsule capsule = Capsule(
      environment: Environment.dev,
      apiKey: '123456',
      relyingPartyId: 'custom.relying.party.id',
      jsBridgeUri: Uri.parse('https://custom.js.bridge.uri/'),
    );

    expect(capsule.environment, Environment.dev);
    expect(capsule.relyingPartyId, 'custom.relying.party.id');
    expect(capsule.jsBridgeUri, Uri.parse('https://custom.js.bridge.uri/'));
  });
}
